The SIDD 2.0 ExploitationFeatures object
========================================

.. automodule:: sarpy.io.product.sidd2_elements.ExploitationFeatures
    :members:
    :show-inheritance:
    :inherited-members:
